mdslibvirt
==========
get access to libvirtd using Python

Install
=======
Ubuntu & Python3:
    sudo apt-get install python3-libvirt

Ubuntu & Python2:
    sudo apt-get install python-libvirt
    

pip install mds-mdslibvirt

Changes
=======

*0.1.0 - 19.12.2018*

- public version
